summaryrefslogtreecommitdiffstats
path: root/krfb/srvloc/kinetinterfacewatcher.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'krfb/srvloc/kinetinterfacewatcher.cpp')
-rw-r--r--krfb/srvloc/kinetinterfacewatcher.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/krfb/srvloc/kinetinterfacewatcher.cpp b/krfb/srvloc/kinetinterfacewatcher.cpp
index 02f21c6c..1e0fa8e6 100644
--- a/krfb/srvloc/kinetinterfacewatcher.cpp
+++ b/krfb/srvloc/kinetinterfacewatcher.cpp
@@ -25,11 +25,11 @@
class KInetInterfaceWatcherPrivate {
public:
- QString interface;
+ TQString interface;
int minInterval; // not used yet, but my be when a daemon watches
- KInetInterfaceWatcherPrivate(const QString &iface,
+ KInetInterfaceWatcherPrivate(const TQString &iface,
int minIntv) :
interface(iface),
minInterval(minIntv) {
@@ -39,17 +39,17 @@ public:
/*
* or all network interfaces.
* @param interface the name of the interface to watch (e.g.'eth0')
* or QString::null to watch all interfaces
* @param minInterval the minimum interval between two checks in
* seconds. Be careful not to check too often, to
* avoid unneccessary wasting of CPU time
*/
-KInetInterfaceWatcher::KInetInterfaceWatcher(const QString &interface,
+KInetInterfaceWatcher::KInetInterfaceWatcher(const TQString &interface,
int minInterval) {
d = new KInetInterfaceWatcherPrivate(interface, minInterval);
}
-QString KInetInterfaceWatcher::interface() const {
+TQString KInetInterfaceWatcher::interface() const {
return d->interface;
}
@@ -39,17 +39,17 @@ public:
* or all network interfaces.
* @param interface the name of the interface to watch (e.g.'eth0')
- * or QString::null to watch all interfaces
+ * or TQString::null to watch all interfaces
* @param minInterval the minimum interval between two checks in
* seconds. Be careful not to check too often, to